@@ -15,8 +15,9 @@ package main
 
 import (
 	"fmt"
-	"github.com/prometheus/snmp_exporter/config"
 	"strconv"
+
+	"github.com/prometheus/snmp_exporter/config"
 )
 
 // The generator config.
@@ -27,11 +28,14 @@ type Config struct {
 }
 
 type MetricOverrides struct {
-	Ignore         bool                              `yaml:"ignore,omitempty"`
-	RegexpExtracts map[string][]config.RegexpExtract `yaml:"regex_extracts,omitempty"`
-	Offset         float64                           `yaml:"offset,omitempty"`
-	Scale          float64                           `yaml:"scale,omitempty"`
-	Type           string                            `yaml:"type,omitempty"`
+	Ignore          bool                              `yaml:"ignore,omitempty"`
+	RegexpExtracts  map[string][]config.RegexpExtract `yaml:"regex_extracts,omitempty"`
+	DateTimePattern string                            `yaml:"datetime_pattern,omitempty"`
+	Offset          float64                           `yaml:"offset,omitempty"`
+	Scale           float64                           `yaml:"scale,omitempty"`
+	Type            string                            `yaml:"type,omitempty"`
+	Help            string                            `yaml:"help,omitempty"`
+	Name            string                            `yaml:"name,omitempty"`
 }
 
 // UnmarshalYAML implements the yaml.Unmarshaler interface.
